@@ -37,14 +37,9 @@ class snakeStorm:
 		self.postData		= {'params': None} # What will get sent if actually passing params
 
 	## Local Parameter Methods ##
-	def addParam(self, key, value):
-		""" Add a single parameter. If already set, it will be overwritten"""
-		self.parameters[key] = value
-
-	def addParams(self, paramDict):
-		""" Add multiple parameters. If a parameter is already set, it will be overwritten. """
-		if isinstance(paramDict, dict):
-			for (key,value) in paramDict.iteritems():
+	def addParams(self, **params):
+		""" Add parameters. If a parameter is already set, it will be overwritten. """
+		for (key,value) in params.iteritems():
 				self.parameters[key] = value
 
 	def clearParams(self):
@@ -55,10 +50,11 @@ class snakeStorm:
 		""" A holdover from me being used to having variable visibility """
 		return self.parameters
 
-	def removeParam(self, key):
-		""" Remove a specific parameter by key """
-		if self.parameters.has_key(key):
-			del self.parameters[key]
+	def removeParams(self, *params):
+		""" Remove specific parameters by key """
+		for key in params:
+			if self.parameters.has_key(key):
+				del self.parameters[key]
 
 	## API Interaction Methods ##
 	def request(self):
